@@ -1,3 +1,5 @@
+#*Coding UTF_8*#
+#Author: TechSmit#
 from licensing import methods
 from licensing.methods import Helpers
 import hashlib
@@ -7,14 +9,20 @@ import os, sys, requests
 class slab:
     @staticmethod
     def auth(auth_id):
+        if auth_id=="":
+            print('Please Enter Authentication id For Verification!')
+            sys.exit()
         global r
-        r=requests.get('https://pastebin.com/'+auth_id)
+        r=('https://pastebin.com/'+auth_id)
+class userid:
     @staticmethod
     def user_id():
         print('USER ID:'+Helpers.GetMachineCode())
+class license:
     @staticmethod
     def verify(username, password, key):
         try:
+            req=requests.get(r)
             #r=requests.get('https://pastebin.com/'+auth_id)
             ke=Helpers.GetMachineCode()
             co=ke.encode('utf-8')
@@ -27,8 +35,8 @@ class slab:
             h=say.hexdigest()
             if h in r.text:
                 if key==KEY:
-                    if e in r.text:
-                        os.system('cls' if os.name=='nt' else 'clear')
+                    if e in req.text:
+                        pass
                     else:
                         print('Invalid Account')
                         sys.exit()
